@@ -1,7 +1,7 @@
 import random
 import string
 from .file import File
-from .misc import items
+from .misc import items,force_bytes
 def _boundary():
     return ''.join(random.choices(string.ascii_letters+string.digits,k=10))
 class Maker:
@@ -12,20 +12,20 @@ class Maker:
         self.fields=fields
         self.headers={"Content-Type":"multipart/form-data; boundary="+self.boundary}
     def make(self):
-        built=''
-        bdr='--'+self.boundary+'\n'
+        built=b''
+        bdr=b'--'+self.boundary.encode()+b'\n'
         for field in items(self.fields):
             built+=bdr
-            disp='Content-Disposition: form-data; name="'+field[0]+'"'
+            disp=b'Content-Disposition: form-data; name="'+force_bytes(field[0])+b'"'
             val=field[1]
-            if isinstance(val,File):
-                disp+='; filename="'+val.name+'"\nContent-Type: '+val.content_type
-                val=val.read().decode()
-            disp+='\n\n'
-            disp+=val+'\n'
+            if issubclass(val.__class__,File):
+                disp+=b'; filename="'+force_bytes(val.name)+b'"\nContent-Type: '+force_bytes(val.content_type)
+                val=val.read()
+            disp+=b'\n\n'
+            disp+=force_bytes(val)+b'\n'
             built+=disp
-        built+=bdr.strip()+'--'
-        return built.encode()
+        built+=bdr.strip()+b'--'
+        return built
 
             
 
